<?php
/* $Id$ */
/* translated by: Airon Luis Pereira <airon(dot)pereira(at)gmail(dot)com> */ 

$charset = 'iso-8859-1'; 
$text_dir = 'ltr';  // ('ltr' da esquerda para direita, 'rtl' da direita para esquerda)
$number_thousands_separator = ','; 
$number_decimal_separator = '.'; 
// abreviaes para Byte, Kilo, Mega, Giga, Tera, Peta, Exa 
$byteUnits = array('Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB'); 

$mysql_4_1_doc_lang = 'pt';

$day_of_week = array('Dom', 'Seg', 'Ter', 'Qua', 'Qui', 'Sex', 'Sab'); 
$month = array('Jan', 'Fev', 'Mar', 'Abr', 'Mai', 'Jun', 'Jul', 'Ago', 'Set', 'Out', 'Nov', 'Dez'); 
// Veja http://www.php.net/manual/en/function.strftime.php para definir
// as variveis abaixo
$datefmt = '%B %d, %Y as %I:%M %p'; 

$timespanfmt = '%s dias, %s horas, %s minutos e %s segundos'; 

$strAbortedClients = 'Abortado'; 
$strAccessDenied = 'Acesso negado'; 
$strAccessDeniedCreateConfig = 'A provvel razo para isso  que voc no criou o arquivo de configurao. Voc deve usar o %1$ssetup script%2$s para criar um.';
$strAccessDeniedExplanation = 'phpMyAdmin tentou se conectar no servidor MySQL e a conxo foi recusada. Voc deve checar o servidor, nome de usurio e senha no config.inc.php e se certificar que correspondam com as informaes fornecidas pelo administrador do servidor MySQL.'; 
$strAction = 'Ao'; 
$strAddAutoIncrement = 'Adicionar valor AUTO_INCREMENT'; 
$strAddClause = 'Adicionar %s';
$strAddConstraints = 'Adicionar restries'; 
$strAddDeleteColumn = 'Adicionar/Remover colunas'; 
$strAddDeleteRow = 'Adicionar/Remover critrios de busca'; 
$strAddFields = 'Adicionar %s campo(s)'; 
$strAddHeaderComment = 'Adicionar comentrio pessoal no cabealho (\\n quebra linhas)'; 
$strAddIntoComments = 'Adicionar nos comentrios'; 
$strAddNewField = 'Adicionar novo campo'; 
$strAddPrivilegesOnDb = 'Adicionar privilgios nas seguintes Banco de Dados'; 
$strAddPrivilegesOnTbl = 'Adicionar privilgios nas seguintes tabelas'; 
$strAddSearchConditions = 'Condio de Pesquisa (complemento da clusula "onde"):'; 
$strAddToIndex = 'Adicionar ao ndice &nbsp;%s&nbsp;coluna(s)'; 
$strAddUser = 'Adicionar novo usurio'; 
$strAddUserMessage = 'Adicionado usurio'; 
$strAdministration = 'Administrao'; 
$strAffectedRows = 'Registro(s) afetado(s):'; 
$strAfter = 'Depois %s'; 
$strAfterInsertBack = 'Retornar'; 
$strAfterInsertNewInsert = 'Inserir novo registro'; 
$strAfterInsertNext = 'Editar prximo registro'; 
$strAfterInsertSame = 'Voltar para esta pgina'; 
$strAllowInterrupt = 'Permitir interromper a importao caso se detecte que o script demorar perto do tempo limite. Isso pode ser um bom caminho para importar arquivos grandes, entretanto isso pode interromper as transaes.';
$strAllTableSameWidth = 'mostrar todas as tabelas com o mesmo tamanho?'; 
$strAll = 'Todos'; 
$strAlterOrderBy = 'Alterar tabela ordenada por'; 
$strAnalyzeTable = 'Analizar tabela'; 
$strAnd = 'E'; 
$strAndThen = 'e ento';
$strAngularLinks = 'Links Angulares';
$strAnIndex = 'Um ndice foi adicionado a %s'; 
$strAnyHost = 'Qualquer servidor'; 
$strAny = 'Qualquer'; 
$strAnyUser = 'Qualquer usurio'; 
$strApproximateCount = 'Pode ser aproximado. Veja o FAQ 3.11'; 
$strAPrimaryKey = 'Uma chave primria foi adicionada a %s'; 
$strArabic = 'rabe'; 
$strArmenian = 'Armno'; 
$strAscending = 'Ascendente'; 
$strAtBeginningOfTable = 'No incio da tabela'; 
$strAtEndOfTable = 'No final da tabela'; 
$strAttr = 'Atributos'; 
$strAutomaticLayout = 'Leiaute automtico'; 

$strBack = 'Voltar'; 
$strBaltic = 'Bltico'; 
$strBeginCut = 'INICIO CORTE'; 
$strBeginRaw = 'INICIO CRU'; 
$strBinary = ' Binrio '; 
$strBinaryDoNotEdit = ' Binrio - no edite '; 
$strBinaryLog = 'Log binrio'; 
$strBinLogEventType = 'Tipo de evento'; 
$strBinLogInfo = 'Informao'; 
$strBinLogName = 'Nome do log'; 
$strBinLogOriginalPosition = 'Posio original'; 
$strBinLogPosition = 'Posio'; 
$strBinLogServerId = 'ID do Servidor'; 
$strBookmarkAllUsers = 'Deixar qualquer usurio acessar esse marcador'; 
$strBookmarkCreated = 'Marcador %s criado';
$strBookmarkDeleted = 'O marcador foi removido.'; 
$strBookmarkLabel = 'Nome'; 
$strBookmarkQuery = 'Consulta SQL gravada'; 
$strBookmarkReplace = 'Substituir marcador de mesmo nome existente';
$strBookmarkThis = 'Gravar essa consulta SQL'; 
$strBookmarkView = 'Apenas visualizar'; 
$strBrowseDistinctValues = 'Navegador distingue valores';
$strBrowseForeignValues = 'Visualizar valores estrangeiros'; 
$strBrowse = 'Visualizar'; 
$strBufferPoolActivity = 'Atividade do Buffer Pool';
$strBufferPool = 'Buffer Pool';
$strBufferPoolUsage = 'Uso do Buffer Pool';
$strBufferReadMissesInPercent = 'Leitura falhou em %';
$strBufferReadMisses = 'Leitura falhou';
$strBufferWriteWaits = 'Escrever as esperas';
$strBufferWriteWaitsInPercent = 'Escrita esperada em %';
$strBulgarian = 'Bulgaro'; 
$strBusyPages = 'Pgina ocupadas';
$strBzError = 'phpMyAdmin no foi capaz de comprimir o dump devido a um defeito na extenso Bz2 desta verso do php.  extremamente recomendado configurar a diretiva <code>$cfg[\'BZipDump\']</code> do arquivo de configurao do phpMyAdmin para <code>FALSE</code>. Se voc quiser usar os recursos de compresso Bz2, voc ter que atualizar para uma verso mais nova do PHP. Veja os relatrios de bug %s do php para detalhes.'; 
$strBzip = '"compactado com bzip"'; 

$strCalendar = 'Calendrio'; 
$strCancel = 'Cancelar';
$strCanNotLoadExportPlugins = 'No pode carregar exportao dos plugins, verifique sua instalao!';
$strCanNotLoadImportPlugins = 'No foi possvel importar plugins, verifique sua instalao!';
$strCannotLogin = 'No foi possvel se logar no servidor MySQL'; 
$strCantLoad = 'no carregou extenso %s,<br />verifique a configuraes do php'; 
$strCantLoadRecodeIconv = 'No  possvel carregar <i>iconv</i> ou recodificar a extenso necessria para a converso do Conjunto de Caracteres, configure o PHP de modo a permitir utilizar estas extenses ou desligue a converso do Conjunto de Caracteres no phpMyAdmin.'; 
$strCantRenameIdxToPrimary = 'No foi possvel renomear o ndice para "PRIMARY"!'; 
$strCantUseRecodeIconv = 'No  possvel usar <i>iconv</i> nem <i>libiconv</i> nem a funo <i>recode_string</i> enquanto a extenso reportar que est ligada. Confira a configurao do seu php.'; 
$strCardinality = 'Cardinalidade'; 
$strCaseInsensitive = 'No diferencia maisculas/minsculas'; 
$strCaseSensitive = 'Diferencia maisculas/minsculas'; 
$strCentralEuropean = 'Europeu Central'; 
$strChange = 'Alterar'; 
$strChangeCopyModeCopy = '... manter o antigo.'; 
$strChangeCopyMode = 'Criar um novo usurio com os mesmos privilgios e ...'; 
$strChangeCopyModeDeleteAndReload = ' ... apagar o antigo da tabela de usurios e depois recarregar os privilgios.'; 
$strChangeCopyModeJustDelete = ' ... apagar o antigo da tabela de usurios.'; 
$strChangeCopyModeRevoke = ' ... revogar todos privilgios do usurio antigo e depois apagar ele.'; 
$strChangeCopyUser = 'Mudar informaes de login / Copiar usurio'; 
$strChangeDisplay = 'Escolha o campo para exibir'; 
$strChangePassword = 'Alterar a senha'; 
$strCharset = 'Conjunto de caracteres'; 
$strCharsetOfFile = 'Conjunto de caracteres do arquivo'; 
$strCharsetsAndCollations = 'Conjuntos de caracteres e Collations'; 
$strCharsets = 'Conjuntos de caracteres'; 
$strCheckAll = 'Marcar todos'; 
$strCheckOverhead = 'Verificar sobre-carga'; 
$strCheckPrivsLong = 'Verificar privilgios para a Banco de Dados &quot;%s&quot;.'; 
$strCheckPrivs = 'Verificar privilgios'; 
$strCheckTable = 'Verificar tabela'; 
$strChoosePage = 'Escolha a pgina para editar'; 
$strColComFeat = 'Exibindo comentrios da coluna'; 
$strCollation = 'Collation'; 
$strColumnNames = 'Nome das colunas'; 
$strColumnPrivileges = 'Privilgios especficos da coluna'; 
$strCommand = 'Comando'; 
$strComments = 'Comentrios'; 
$strCommentsForTable = 'COMENTRIOS PARA A TABELA'; 
$strCompatibleHashing = 'Compatvel com MySQL&nbsp;4.0'; 
$strCompleteInserts = 'Inseres completas'; 
$strCompression = 'Compresso'; 
$strCompressionWillBeDetected = 'Compresso do arquivo importado ser automaticamente detectada de: %s';
$strConfigDefaultFileError = 'No foi possvel carregar configurao padro de: "%1$s"';
$strConfigFileError = 'O phpMyAdmin no foi capaz de ler o arquivo de configurao!<br />Isto pode acontecer se o php encontrar um erro no <i>parsing</i> ou se no conseguir encontrar o arquivo.<br />Chame o arquivo de configurao diretamente usando o <i>link</i> abaixo e leia a(s) mensagem(ns) de erro do php. Na maior parte dos casos, trata-se de uma falta de aspas ou de um ponto e vrgula errado.<br />Se receber uma pgina em branco, est tudo certo.'; 
$strConfigureTableCoord = 'Configure as coordenadas para a tabela %s'; 
$strConnectionError = 'No pode conectar: configuraes invlidas.'; 
$strConnections = 'Conexes'; 
$strConstraintsForDumped = 'Restries para as tabelas dumpadas'; 
$strConstraintsForTable = 'Restries para a tabela'; 
$strControluserFailed = 'Conexo para controle do usurio como definido nas configuraes falhou.';
$strCookiesRequired = 'Cookies devem estar ativos aps este ponto.'; 
$strCopy = 'Copiar';
$strCopyDatabaseOK = 'Banco de Dados %s copiado para %s'; 
$strCopyTable = 'Copiar tabela para (Banco de Dados<b>.</b>tabela):'; 
$strCopyTableOK = 'Tabela %s copiada para %s.'; 
$strCopyTableSameNames = 'No pode copiar a tabela para ela mesma!'; 
$strCouldNotKill = 'phpMyAdmin no foi capaz de matar o processo %s.  possvel que ele j esteja fechado.'; 
$strCreate = 'Criar'; 
$strCreateDatabaseBeforeCopying = 'CREATE DATABASE antes de copiar';
$strCreateIndex = 'Criar um ndice em&nbsp;%s&nbsp;colunas'; 
$strCreateIndexTopic = 'Criar um novo ndice'; 
$strCreateNewDatabase = 'Criar novo Banco de Dados'; 
$strCreateNewTable = 'Criar nova tabela no Banco de Dados %s'; 
$strCreatePage = 'Criar uma nova pgina'; 
$strCreatePdfFeat = 'Criao de PDFs'; 
$strCreateRelation = 'Criar relacionamento';
$strCreateTable  = 'Criar tabela';
$strCreateUserDatabase = 'Banco de Dados para usurio';
$strCreateUserDatabaseName = 'Criar Banco de Dados com o mesmo nome e conceder todos os privilgios';
$strCreateUserDatabaseNone = 'Nenhum';
$strCreateUserDatabaseWildcard = 'Conceder todos os privilgios no nome coringa (nome_do_usurio_%)';
$strCreationDates = 'Criar/Atualizar/Verificar datas'; 
$strCriteria = 'Critrio'; 
$strCroatian = 'Croata'; 
$strCSV = 'CSV';
$strCyrillic = 'Cirlico'; 
$strCzechSlovak = 'Tcheco-Eslovquio'; 
$strCzech = 'Tcheco'; 

$strDanish = 'Dinamarqus'; 
$strDatabase = 'Banco de Dados'; 
$strDatabaseEmpty = 'O nome do Banco de Dados est em branco!'; 
$strDatabaseExportOptions = 'Opes de exportao do Banco de Dados'; 
$strDatabaseHasBeenDropped = 'Banco de Dados %s foi eliminado.'; 
$strDatabases = 'Banco de Dados'; 
$strDatabasesDropped = 'Banco de Dados %s foi eliminado com sucesso!'; 
$strDatabasesStatsDisable = 'Disabilitar estatsticas'; 
$strDatabasesStatsEnable = 'Habilitar estatsticas'; 
$strDatabasesStats = 'Estatsticas do Banco de Dados'; 
$strDatabasesStatsHeavyTraffic = 'Nota: Ativar as estatsticas pode causar um grande volume de trfego de dados entre o servidor web e o servidor MySQL.'; 
$strData = 'Dados'; 
$strDataDict = 'Dicionrio de dados'; 
$strDataOnly = 'Dados apenas'; 
$strDataPages = 'Pginas contendo dados';
$strDBComment = 'Comentrio do Banco de Dados: '; 
$strDBCopy = 'Copiar Banco de Dados para'; 
$strDbIsEmpty = 'Banco de Dados parece estar vazio!';
$strDbPrivileges = 'Privilgios especficos do Banco de Dados'; 
$strDBRename = 'Renomear Banco de Dados para'; 
$strDbSpecific = 'Especfico do Banco de Dados'; 
$strDefaultEngine = '%s  o stored engine padro neste servidor MySQL.';
$strDefault = 'Padro'; 
$strDefaultValueHelp = 'Para valores padro, digite um valor simples, sem barras de escape ou aspas, use este formato: a'; 
$strDefragment = 'Desfragmentar tabela'; 
$strDelayedInserts = 'Usar inseres demoradas'; 
$strDeleteAndFlush = 'Apagar usurio e depois recarregar os privilgios.'; 
$strDeleteAndFlushDescr = 'Esse  o caminho mais claro, mas recarregar os privilgios pode demorar um pouco.'; 
$strDeleted = 'Registro eliminado'; 
$strDeletedRows = 'Registros eliminados:'; 
$strDeleteNoUsersSelected = 'Nenhum usurio selecionado para excluso!';
$strDeleteRelation = 'Apagar relacionamento';
$strDelete = 'Remover'; 
$strDeleting = 'Eliminando %s'; 
$strDelimiter = 'Delimitadores';
$strDelOld = 'A Pgina atual contm referncias para uma tabela que no existe. Gostaria de eliminar estas referncias?'; 
$strDescending = 'Descendente'; 
$strDescription = 'Descrio'; 
$strDesigner = 'Designer';
$strDesignerHelpDisplayField = 'O campo de exibio est em rosa. Para ajustar/desajustar um campo como campo de exibio, clique no cone "Escolher campo para exibio", ento clique no nome do campo apropriado.';
$strDictionary = 'dicionrio'; 
$strDirectLinks = 'Links diretos';
$strDirtyPages = 'Pginas sujas';
$strDisabled = 'Desabilitado'; 
$strDisableForeignChecks = 'Desabilitar verificao de chaves estrangeiras'; 
$strDisplayFeat = 'Exibir recursos'; 
$strDisplayOrder = 'Ordenado por:'; 
$strDisplayPDF = 'Exibir esquema PDF'; 
$strDoAQuery = 'Faa uma "consulta por exemplo" (coringa: "%")'; 
$strDocSQL = 'DocSQL';
$strDocu = 'Documentao'; 
$strDoYouReally = 'Confirmar'; 
$strDropDatabaseStrongWarning = 'Voc est prestes  DESTRUIR completamente o Banco de Dados!'; 
$strDrop = 'Eliminar'; 
$strDropUsersDb = 'Eliminar o Banco de Dados que possui o mesmo nome dos usurios.'; 
$strDumpingData = 'Extraindo dados da tabela'; 
$strDumpSaved = 'Dump foi salvo no arquivo %s.'; 
$strDumpXRows = 'Dumpar %s registros, comeando pelo registro %s.'; 
$strDynamic = 'dinmico'; 

$strEdit = 'Editar'; 
$strEditPDFPages = 'Editar Pginas PDF'; 
$strEditPrivileges = 'Editar Privilgios'; 
$strEffective = 'Efetivo'; 
$strEmpty = 'Limpar'; 
$strEmptyResultSet = 'MySQL retornou um conjunto vazio (ex. zero registros).'; 
$strEnabled = 'Habilitado'; 
$strEncloseInTransaction = 'Encapsular exportao numa transao'; 
$strEndCut = 'FIM CORTE'; 
$strEnd = 'Fim'; 
$strEndRaw = 'FIM CRU'; 
$strEngineAvailable = '%s est disponvel neste servidor MySQL.';
$strEngineDisabled = '%s est desabilitado neste servidor MySQL.';
$strEngines = 'Engines'; //sem traducao
$strEngineUnsupported = 'Esse servidor MySQL no suporta o stored engine %s.';
$strEnglish = 'Ingls'; 
$strEnglishPrivileges = ' Nota: nomes de privilgios do MySQL so expressos em ingls '; 
$strError = 'Erro'; 
$strErrorInZipFile = 'Erro no arquivo ZIP:';
$strErrorRelationAdded = 'Erro: relacionamento no adicionado.';
$strErrorRelationExists = 'Erro: relacionamento j existe.';
$strErrorRenamingTable = 'Erro ao renomear tabela %1$s para %2$s';
$strErrorSaveTable = 'Erro ao salvar coordenada para o Designer.';
$strEscapeWildcards = 'Coringas _ e % precisam ser precedidos com uma \ para serem usados literalmente'; 
$strEsperanto = 'Esperanto';
$strEstonian = 'Estoniano'; 
$strEvent = 'Evento';
$strExcelEdition = 'Edio do Excel'; 
$strExecuteBookmarked = 'Executar consulta marcada'; 
$strExplain = 'Explicar SQL'; 
$strExport = 'Exportar'; 
$strExportImportToScale = 'Exportar/Importar para escala';
$strExportMustBeFile = 'Tipo de exportao selecionada tem que ser salva no arquivo!';
$strExtendedInserts = 'Inseres extendidas'; 
$strExtra = 'Extra'; 

$strFailedAttempts = 'Tentativas falharam'; 
$strField = 'Campo'; 
$strFieldHasBeenDropped = 'Campo %s foi deletado'; 
$strFieldInsertFromFileTempDirNotExists = 'Erro ao mover o arquivo carregado, veja FAQ 1.11';
$strFields = 'Campos'; 
$strFieldsEnclosedBy = 'Campos delimitados por'; 
$strFieldsEscapedBy = 'Campos contornados por'; 
$strFieldsTerminatedBy = 'Campos terminados por'; 
$strFileAlreadyExists = 'O arquivo %s j existe no servidor, mude o nome do arquivo ou verifique sua opo de sobrescrever.'; 
$strFileCouldNotBeRead = 'O arquivo no pode ser lido'; 
$strFileNameTemplateDescriptionDatabase = 'nome do Banco de Dados';
$strFileNameTemplateDescription = 'Esse valor  interpretado usando %1$sstrftime%2$s, ento voc pode usar as strings de formatao de tempo. Adicionalmente a seguinte transformao ocorrer: %3$s. Outros textos sero mantidos como so.';
$strFileNameTemplateDescriptionServer = 'nome do servidor';
$strFileNameTemplateDescriptionTable = 'nome da tabela';
$strFileNameTemplate = 'Nome do arquivo do modelo'; 
$strFileNameTemplateRemember = 'lembrar modelo'; 
$strFiles = 'Arquivos';
$strFileToImport = 'Arquivo para importar';
$strFixed = 'fixo'; 
$strFlushPrivilegesNote = 'Nota: O phpMyAdmin recebe os privilgios dos usurio diretamente da tabela de privilgios do MySQL. O contedo destas tabelas pode divergir dos privilgios que o servidor usa se alteraes manuais forem feitas nele. Neste caso, voc deve usar %sRELOAD PRIVILEGES%s antes de continuar..'; 
$strFlushQueryCache = 'Nivelar cache da consulta';  //est correto isso?
$strFlushTable = 'Limpar a tabela ("LIMPAR")'; 
$strFlushTables = 'Nivelar (fechar) todas as tabelas';  //est correto isso?
$strFontSize = 'Tamanho da fonte';
$strForeignKeyError = 'Erro na criao da chave estrangeira (cheque o tipo de dado)';
$strFormat = 'Formato'; 
$strFormEmpty = 'Faltando valores no formulrio!'; 
$strFreePages = 'Pginas livres';
$strFullText = 'Textos completos'; 
$strFunction = 'Funes'; 
$strFunctions = 'Funes';

$strGenBy = 'Gerado por'; 
$strGeneralRelationFeat = 'Recursos de relaes gerais'; 
$strGenerate = 'Gerar';
$strGeneratePassword = 'Gerar Senha';
$strGenTime = 'Tempo de Gerao'; 
$strGeorgian = 'Georgiano'; 
$strGerman = 'Alemo'; 
$strGlobal = 'global'; 
$strGlobalPrivileges = 'Privilgios globais'; 
$strGlobalValue = 'Valor global'; 
$strGo = 'Executar'; 
$strGrantOption = 'Conceder/Grant'; 
$strGreek = 'Grego'; 
$strGzip = '"compactado com gzip"'; 

$strHandler = 'Alimentador';  //est correto isso? seria Gestor??
$strHasBeenAltered = 'foi alterado.'; 
$strHasBeenCreated = 'foi criado.'; 
$strHaveToShow = 'Deve escolher pelo menos uma coluna para exibir'; 
$strHebrew = 'Hebreu'; 
$strHelp = 'Ajuda';
$strHexForBLOB = 'Usar hexadecimal para BLOB';
$strHide = 'Ocultar';
$strHideShowAll = 'Ocultar/Exibir tudo';
$strHideShowNoRelation = 'Ocultar/Exibir Tabelas sem relacionamento';
$strHomepageOfficial = 'Pgina Oficial do phpMyAdmin'; 
$strHome = 'Principal'; 
$strHostEmpty = 'O nome do servidor est vazio!'; 
$strHost = 'Servidor'; 
$strHTMLExcel = 'Microsoft Excel 2000';
$strHTMLWord = 'Microsoft Word 2000';
$strHungarian = 'Hngaro'; 

$strIcelandic = 'Islands'; 
$strId = 'ID'; 
$strIdxFulltext = 'Texto completo'; 
$strIEUnsupported = 'Internet Explorer no suporta esta funo.';
$strIgnoreDuplicates = 'Ignorar linhas duplicadas';
$strIgnore = 'Ignorar'; 
$strIgnoreInserts = 'Usar inseres ignoradas'; 
$strImportExportCoords = 'Importar/Exportar coordenadas para esquema PDF';
$strImportFiles = 'Importar arquivos'; 
$strImportFormat = 'Formato do arquivo importado';
$strImport = 'Importar';
$strImportSuccessfullyFinished = 'Importao finalizada com sucesso, %d consultas executadas.';
$strIndexes = 'ndices'; 
$strIndexesSeemEqual = 'Os seguintes ndices parecem ser idnticos e um deles deve ser removido:';
$strIndexHasBeenDropped = 'ndice %s foi eliminado'; 
$strIndex = 'ndice'; 
$strIndexName = 'Nome do ndice:'; 
$strIndexType = 'Tipo de ndice:'; 
$strIndexWarningTable = 'Problemas com o ndice da tabela `%s`'; 
$strInnoDBAutoextendIncrementDesc = 'O tamanho do incremento para extender o tamanho de um tamanho de tabela autoextendida quando ela comear  ficar cheia.';
$strInnoDBAutoextendIncrement = 'Incremento autoextendido';
$strInnoDBBufferPoolSizeDesc = 'O tamanho do buffer de memria que o InnoDB usa para dados do cache e ndices nas suas tabelas.';
$strInnoDBBufferPoolSize = 'Tamanho do Buffer Pool';
$strInnoDBDataFilePath = 'Arquivos de dados';
$strInnoDBDataHomeDirDesc = 'A parte comum do caminho do diretrio para todos os arquivos de dados do InnoDB.';
$strInnoDBDataHomeDir = 'Diretrio raiz de dados';
$strInnoDBPages = 'pginas';
$strInnoDBRelationAdded = 'Adicionado relacionamento InnoDB';
$strInnodbStat = 'Status do InnoDB'; 
$strInsecureMySQL = 'O seu arquivo de configurao contm configuraes (root sem senha) que correspondem  conta privilegiada padro do MySQL. O servidor MySQL rodando com esse padro estar aberto a invases, voc realmente deveria corrigir este furo de segurana.'; 
$strInsertAsNewRow = 'Inserir como um novo registro'; 
$strInsertedRowId = 'Inserir ID do registro:'; 
$strInsertedRows = 'Registros inseridos:'; 
$strInsert = 'Inserir'; 
$strInternalNotNecessary = '* No  necessria uma relao interna quando tambm j existe na InnoDB.'; 
$strInternalRelationAdded = 'Adicionado relacionamento Interno';
$strInternalRelations = 'Relaes internas'; 
$strInUse = 'em uso'; 
$strInvalidAuthMethod = 'Mtodo de autenticao invlido informado nas configuraes:';
$strInvalidColumn = 'Coluna especificada (%s)  invlida!';
$strInvalidColumnCount = 'Contador da coluna deve ser maior que zero.';
$strInvalidCSVFieldCount = 'Contador de campo invlido na linha %d da entrada CSV.';
$strInvalidCSVFormat = 'Formato invlido na linha %d da entrada CSV.';
$strInvalidCSVParameter = 'Parmetro invlido para importao CSV: %s';
$strInvalidDatabase = 'Banco de Dados invlido';
$strInvalidFieldAddCount = 'Voc deve adicionar pelo menos um campo.';
$strInvalidFieldCount = 'Tabela deve ter pelo menos um campo.';
$strInvalidLDIImport = 'Esse plugin no suporta importaes comprimidas!';
$strInvalidRowNumber = '%d no  um nmero de linha vlido.';
$strInvalidServerHostname = 'Nome de serivdor invlido para o servidor %1$s. Verifique suas configuraes.';
$strInvalidServerIndex = 'ndice de servidor invlido: "%s"';
$strInvalidTableName = 'Nome de tabela invlida';

$strJapanese = 'Japons'; 
$strJoins = 'Junes';
$strJumpToDB = 'Ir para o Banco de Dados &quot;%s&quot;.'; 
$strJustDelete = 'Apenas apagar o usurio da tabela de privilgios'; 
$strJustDeleteDescr = 'O usurio &quot;apagado&quot; ainda podera continuar acessando o servidor normalmente at que os privilgios sejam recarregados.'; 

$strKeepPass = 'No mudar a senha'; 
$strKeyCache = 'Chave do cache';
$strKeyname = 'Nome chave'; 
$strKill = 'Matar'; 
$strKnownExternalBug = 'A funcionalidade %s  afetada por um bug conhecido, veja %s';
$strKorean = 'Coreano'; 

$strLandscape = 'Paisagem'; 
$strLanguage = 'Linguagem';
$strLanguageUnknown = 'Linguagem desconhecida: %1$s.';
$strLatchedPages = 'Pginas trancadas';
$strLatexCaption = 'Leganda da Tabela'; 
$strLatexContent = 'Contedo da tabela __TABLE__'; 
$strLatexContinuedCaption = 'Continuao da legenda da tabela'; 
$strLatexContinued = '(continuao)'; 
$strLatexIncludeCaption = 'Incluir legenda da tabela'; 
$strLatexLabel = 'Rtulo da chave'; 
$strLaTeX = 'LaTeX'; 
$strLatexStructure = 'Estrutura da tabela __TABLE__'; 
$strLatvian = 'Letons'; 
$strLDI = 'CSV usando LOAD DATA';
$strLDILocal = 'Usar palavra-chave LOCAL';
$strLengthSet = 'Tamanho/Definir*'; 
$strLimitNumRows = 'registros por pgina'; 
$strLinesTerminatedBy = 'Linhas terminadas por'; 
$strLinkNotFound = 'Link no encontrado'; 
$strLinksTo = 'Links para'; 
$strLithuanian = 'Litunio'; 
$strLocalhost = 'Local'; 
$strLocationTextfile = 'Localizao do arquivo texto'; 
$strLogin = 'Autenticao'; 
$strLoginInformation = 'Informao de login'; 
$strLogout = 'Sair'; 
$strLogPassword = 'Senha:'; 
$strLogServer = 'Servidor'; 
$strLogUsername = 'Usurio:'; 
$strLongOperation = 'Esta operao pode ser demorada. Deseja prosseguir?';

$strMaxConnects = 'mx. de conexes concorrentes';
$strMaximalQueryLength = 'Tamanho mximo da consulta gerada';
$strMaximumSize = 'Tamanho mximo: %s%s'; 
$strMbExtensionMissing = 'A extenso mbstring do PHP no foi encontrada e voc parece estar usando conjuntos de caracteres multibyte. Sem a extenso mbstring o phpMyAdmin no ser capaz de dividir as strings corretamente isso pode causar resultados inesperados.'; 
$strMbOverloadWarning = 'Voc habilitou mbstring.func_overload nas configuraes do PHP. Essa opo  incompatvel com o phpMyAdmin e certamente causar a perda de algum dado!'; 
$strMIME_available_mime = 'MIME-type disponveis'; 
$strMIME_available_transform = 'Transformaes disponveis'; 
$strMIME_description = 'Descrio'; 
$strMIME_MIMEtype = 'MIME-type'; // MIME-types nao tem traducao
$strMIME_nodescription = 'Sem descrio disponvel para essa transformao.<br />Pergunte ao autor o que %s faz.'; 
$strMIME_transformation_note = 'Para uma lista de opes de transformao disponveis e suas transformaes MIME-type, clique em %sdescrio de transformaes%s'; 
$strMIME_transformation_options_note = 'Digite os valores para as opes de transformao usando este formato: \'a\', 100, b,\'c\'...<br />Se por acaso precisar inserir uma contra-barra ("\") ou aspas ("\'") no meio desses valores, faa-o usando outra contra-barra (por exemplo \'\\\\xyz\' ou \'a\\\'b\').'; 
$strMIME_transformation_options = 'Opes de transformao'; 
$strMIME_transformation = 'Transformaes do navegador'; 
$strMIMETypesForTable = 'MIME-TYPES PARA AS TABELAS'; 
$strMIME_without = 'MIME-types em itlico no tm uma funo de transformao separada'; 
$strModifications = 'Modificaes foram salvas'; 
$strModifyIndexTopic = 'Modificar um ndice'; 
$strModify = 'Modificar'; 
$strMoveMenu = 'Mover Menu';
$strMoveTable = 'Mover tabela para (Banco de Dados<b>.</b>tabela):'; 
$strMoveTableOK = 'Tabela %s foi movida para %s.'; 
$strMoveTableSameNames = 'No pode mover a tabela para ela mesma!'; 
$strMultilingual = 'multi-linguagem'; 
$strMyISAMDataPointerSizeDesc = 'O tamanho padro do ponteiro em bytes, para ser usado por CREATE TABLE para tabelas MyISAM quando a opo MAX_ROWS no  especificada.';
$strMyISAMDataPointerSize = 'Tamanho do ponteiro de dados';
$strMyISAMMaxExtraSortFileSizeDesc = 'Se os arquivos temporrios usados para rpida criao de ndices MyISAM forem maiores do que usando a chave do cache pela quantidade especificada aqui, prefira o mtodo chave do cache.';
$strMyISAMMaxExtraSortFileSize = 'Tamanho mximo para arquivos temporrios na criao do ndice';
$strMyISAMMaxSortFileSizeDesc = 'O tamanho mximo do arquivo temporrio MySQL que  permitido usar quando for recriar um ndice MyISAM (durante REPAIR TABLE, ALTER TABLE ou LOAD DATA INFILE).';
$strMyISAMMaxSortFileSize = 'Tamanho mximo para os arquivos temporrios de ordenao';
$strMyISAMRecoverOptionsDesc = 'O modo para recuperao automtica de tabelas MyISAM danificadas, como configurado pela opo de inicializao do servidor --myisam-recover.';
$strMyISAMRecoverOptions = 'Modo de recuperao automtico';
$strMyISAMRepairThreadsDesc = 'Se este valor for maior que 1, ndices das tabelas MyISAM so criados em paralelo (cada ndice tem seu prprio processo) durante o Reparo pelo processo de ordenao.';
$strMyISAMRepairThreads = 'Processos de reparo';
$strMyISAMSortBufferSizeDesc = 'O buffer que  alocado quando so ordenados ndices MyISAM durante um REPAIR TABLE ou quando so criados ndices com CREATE INDEX ou ALTER TABLE.';
$strMyISAMSortBufferSize = 'Tamanho do buffer de ordenao';
$strMySQLCharset = 'Conjunto de caracteres MySQL'; 
$strMysqlClientVersion = 'Verso do cliente MySQL';
$strMySQLConnectionCollation = 'Collation de conexo do MySQL'; // Collation nao tem traducao
$strMysqlLibDiffersServerVersion = 'Sua verso %s da biblioteca MySQL do PHP difere da verso %s do seu servidor MySQL. Isso pode causar um comportamento estranho.';
$strMySQLSaid = 'Mensagens do MySQL : '; 
$strMySQLShowProcess = 'Mostrar os Processos'; 
$strMySQLShowStatus = 'Mostrar informao de runtime do MySQL'; 
$strMySQLShowVars = 'Mostrar variveis de sistema do MySQL'; 

$strName = 'Nome'; 
$strNext = 'Prximo'; 
$strNoActivity = 'Sem atividade por %s segundos ou mais, faa o login novamente'; 
$strNoDatabasesSelected = 'Nenhum Banco de Dados selecionado.'; 
$strNoDatabases = 'Sem bases'; 
$strNoDataReceived = 'Nenhum dado foi recebido pra importar. Tampouco um nome de arquivo foi submetido, ou o tamanho do arquivo excedeu o tamanho mximo permitido pelas suas configuraes do PHP. Veja FAQ 1.16.';
$strNoDescription = 'sem Descrio'; 
$strNoDetailsForEngine = 'No h nenhuma informao detalhada do status disponvel para esta storage engine.';
$strNoDropDatabases = 'O comando "DROP DATABASE" est desabilitado.'; 
$strNoExplain = 'Pular Explicao SQL'; 
$strNoFilesFoundInZip = 'Nenhum arquivo encontrado dentro do arquivo ZIP!';
$strNoFrames = 'phpMyAdmin  mais amigvel com um navegador <b>capaz de exibir frames</b>.'; 
$strNoIndex = 'Nenhum ndice definido!'; 
$strNoIndexPartsDefined = 'Nenhuma parte de ndice definida!'; 
$strNoModification = 'Sem Mudana'; 
$strNo = 'No'; 
$strNone = 'Nenhum'; 
$strNoOptions = 'Esse formato no tem opes'; 
$strNoPassword = 'Sem senha'; 
$strNoPermission = 'O servidor web no tem permisso para salvar o arquivo %s.'; 
$strNoPhp = 'sem cdigo PHP'; 
$strNoPrivileges = 'Sem privilgios'; 
$strNoRights = 'Voc no tem direitos suficientes para estar aqui agora!'; 
$strNoRowsSelected = 'Nenhum registro selecionado'; 
$strNoSpace = 'Espao insuficiente para salvar o arquivo %s.'; 
$strNoTablesFound = 'Nenhuma tabela encontrada no Banco de Dados'; 
$strNoThemeSupport = 'Sem suporte a Temas, verifique suas configuraes e/ou seus Temas no diretrio %s.'; 
$strNotNumber = 'Isto no  um nmero!'; 
$strNotOK = 'no est OK'; 
$strNotSet = '<b>%s</b> tabela no encontrada ou no configurada em %s'; 
$strNoUsersFound = 'Nenhum usurio(s) encontrado.'; 
$strNoValidateSQL = 'Pular validao SQL'; 
$strNull = 'Nulo'; 
$strNumberOfFields = 'Nmero de arquivos';
$strNumberOfTables = 'Numero de tabelas';
$strNumSearchResultsInTable = '%s resultado(s) dentro da tabela <i>%s</i>'; 
$strNumSearchResultsTotal = '<b>Total:</b> <i>%s</i> resultado(s)'; 
$strNumTables = 'Tabelas'; 

$strOK = 'OK'; 
$strOpenDocumentSpreadsheet = 'Abrir Documento Planilha';
$strOpenDocumentText = 'Abrir Documento de Texto';
$strOpenNewWindow = 'Abrir nova janela do phpMyAdmin';
$strOperations = 'Operaes'; 
$strOperator = 'Operador'; 
$strOptimizeTable = 'Otimizar tabela'; 
$strOptions = 'Opes';
$strOr = 'Ou'; 
$strOverhead = 'Sobrecarga'; 
$strOverwriteExisting = 'Sobrescrever arquivo(s) existente(s)'; 

$strPageNumber = 'Numero da pgina:'; 
$strPagesToBeFlushed = 'Pginas para serem niveladas';
$strPaperSize = 'Tamanho do papel'; 
$strPartialImport = 'Importao parcial';
$strPartialText = 'Textos parciais'; 
$strPasswordChanged = 'A senha para %s foi modificada com sucesso.'; 
$strPasswordEmpty = 'A senhas est em branco!'; 
$strPasswordHashing = 'Hashing da senha'; // Hashing nao tem traducao
$strPasswordNotSame = 'As senhas no so iguais!'; 
$strPassword = 'Senha'; 
$strPdfDbSchema = 'Esquema do Banco de Dados "%s" - Pgina %s'; 
$strPdfInvalidTblName = 'A tabela "%s" no existe!'; 
$strPdfNoTables = 'Sem tabelas'; 
$strPDF = 'PDF';
$strPDFReportExplanation = '(Gerado um relatrio contendo dados da tabela simples)';
$strPDFReportTitle = 'Ttulo do Relatrio';
$strPerHour = 'por hora'; 
$strPerMinute = 'por minuto'; 
$strPerSecond = 'por segundo'; 
$strPersian = 'Prsa'; 
$strPhoneBook = 'Agenda de telefones'; 
$strPHP40203 = 'Voc est usando o PHP 4.2.3, que possui um grave defeito usando strings multi-byte (mbstring). Veja relatrio 19404 de erros do PHP. Essa verso no  recomendada para uso com o phpMyAdmin.'; 
$strPhp = 'Criar cdigo PHP'; 
$strPHPVersion = 'Verso do PHP'; 
$strPleaseSelectPrimaryOrUniqueKey = 'Por favor, selecione uma chave primria ou uma chave nica';
$strPmaDocumentation = 'Documentao do phpMyAdmin '; 
$strPmaUriError = 'A varivel <tt>$cfg[\'PmaAbsoluteUri\']</tt> deve ser setada'; 
$strPmaWiki = 'Wiki phpMyAdmin';
$strPolish = 'Polons'; 
$strPortrait = 'Retrato'; 
$strPos1 = 'Incio'; 
$strPrevious = 'Anterior'; 
$strPrimaryKeyHasBeenDropped = 'A chave primria foi deletada'; 
$strPrimaryKeyName = 'O nome da chave primria deve ser... "PRIMARY"!'; 
$strPrimaryKeyWarning = '("PRIMARY" <b>precisa</b> ser o nome <b>de</b> e <b>apenas da</b> chave primria!)'; 
$strPrimary = 'Primria'; 
$strPrint = 'Imprimir'; 
$strPrintViewFull = 'Ver impresso (com textos completos)'; 
$strPrintView = 'Visualizao para impresso'; 
$strPrivDescAllPrivileges = 'Incluir todos os privilgios, exceto GRANT.'; 
$strPrivDescAlter = 'Permitir alterar a estrutura das tabelas existentes.'; 
$strPrivDescAlterRoutine = 'Permitir alterar e apagar stored routines.';
$strPrivDescCreateDb = 'Permitir criar novas tabelas e Banco de Dados.'; 
$strPrivDescCreateRoutine = 'Permitir criar stored routines.';
$strPrivDescCreateTbl = 'Permitir criar novas tabelas.'; 
$strPrivDescCreateTmpTable = 'Permitir criar tabelas temporrias.'; 
$strPrivDescCreateUser = 'Permitir criar, apagar e renomear contas dos usurios.';
$strPrivDescCreateView = 'Permitir criar novas vises.';
$strPrivDescDelete = 'Permitir apagar dados.'; 
$strPrivDescDropDb = 'Permitir eliminar Banco de Dados e tabelas.'; 
$strPrivDescDropTbl = 'Permitir eliminar tabelas.'; 
$strPrivDescExecute5 = 'Permitir executar stored routines.';
$strPrivDescExecute = 'Permitir rodar "stored procedures"; Sem efeitos nesta verso do MySQL.'; 
$strPrivDescFile = 'Permitir importar dados e exportar dados em arquivos.'; 
$strPrivDescGrant = 'Permitir adicionar usurios e privilgios sem recarregar a tabela de privilgios.'; 
$strPrivDescIndex = 'Permitir criar e eliminar ndices.'; 
$strPrivDescInsert = 'Permitir inserir e substituir dados.'; 
$strPrivDescLockTables = 'Permitir bloquear tabelas para a processo atual.'; 
$strPrivDescMaxConnections = 'Limitar o numero de novas conexes que o usurio pode abrir por hora.'; 
$strPrivDescMaxQuestions = 'Limitar o nmero de consultas que podem ser enviadas ao servidor por hora.'; 
$strPrivDescMaxUpdates = 'Limitar o nmero de comandos que alteram Bancos de Dados ou tabelas que o usurio pode executar por hora.'; 
$strPrivDescMaxUserConnections = 'Limitar o nmero de conexes simultneas que o usurio pode ter.';
$strPrivDescProcess3 = 'Permitir matar os processos de outros usurios.'; 
$strPrivDescProcess4 = 'Permitir visualizar consultas completas da lista de processos.'; 
$strPrivDescReferences = 'Sem efeitos nesta verso do MySQL.'; 
$strPrivDescReload = 'Permitir recarregar configuraes do servidor e descarregar o cache do servidor.'; 
$strPrivDescReplClient = 'Permitir que o usurio pergunte onde esto os escravos / mestres.'; 
$strPrivDescReplSlave = 'Precisar dos escravos de replicao.'; 
$strPrivDescSelect = 'Permitir leitura dos dados.'; 
$strPrivDescShowDb = 'Permitir acesso completo  lista de Bancos de Dados.'; 
$strPrivDescShowView = 'Permitir executar consultas SHOW CREATE VIEW.';
$strPrivDescShutdown = 'Permitir desligar o servidor.'; 
$strPrivDescSuper = 'Permitir conectar, se o numero mximo de conexes for alcanado; Necessrio para muitas operaes administrativas, como setar variveis globais e matar processos de outros usurios.'; 
$strPrivDescUpdate = 'Permitir modificar dados.'; 
$strPrivDescUsage = 'Sem privilgios.'; 
$strPrivileges = 'Privilgios'; 
$strPrivilegesReloaded = 'Os privilgios foram recarregados com sucesso.'; 
$strProcedures = 'Procedimentos';
$strProcesses = 'Processos'; 
$strProcesslist = 'Lista de processos'; 
$strProtocolVersion = 'Verso do Protocolo';
$strPutColNames = 'Colocar nome do campo na primeira linha'; 

$strQBEDel = 'Del';   // (used in tbl_qbe.php) 
$strQBEIns = 'Ins';   // (used in tbl_qbe.php) 
$strQBE = 'Procurar por exemplo'; 
$strQueryCache = 'Consulta do cache';
$strQueryFrame = 'Janela de consulta'; 
$strQueryOnDb = 'Consulta no Banco de Dados <b>%s</b>:'; 
$strQueryResultsOperations = 'Operaes resultantes das consultas';
$strQuerySQLHistory = 'Histrico de consultas'; 
$strQueryStatistics = '<b>Estatsticas das consultas</b>: Desde o incio, %s consultas foram enviadas para o servidor.'; 
$strQueryTime = 'Consulta levou %01.4f segundos'; 
$strQueryType = 'Tipo de consulta'; 
$strQueryWindowLock = 'No sobrescrever esta consulta fora desta janela'; 

$strReadRequests = 'Leitura requisitada';
$strReceived = 'Recebido'; 
$strRecommended = 'recomendado';
$strRecords = 'Registros'; 
$strReferentialIntegrity = 'Verificar integridade referencial:'; 
$strRefresh = 'Atualizar'; 
$strRelationalSchema = 'Esquema relacional'; 
$strRelationDeleted = 'Relacionamento apagado';
$strRelationNotWorking = 'Os recursos adicionais para trabalhar com tabelas linkadas foram desativadas. Para descobrir o motivo clique %saqui%s.'; 
$strRelationsForTable = 'RELAES PARA A TABELA'; 
$strRelations = 'Relaes'; 
$strRelationView = 'Ver relaes'; 
$strReloadingThePrivileges = 'Recarregando os privilgios'; 
$strReloadPrivileges = 'Recarregar privilgios';
$strReload = 'Recarregar';
$strRemoveSelectedUsers = 'Remover os usurios selecionados'; 
$strRenameDatabaseOK = 'O Banco de Dados %s foi renomeado para %s'; 
$strRenameTableOK = 'Tabela %s renomeada para %s'; 
$strRenameTable = 'Renomear a tabela para '; 
$strRepairTable = 'Reparar tabela'; 
$strReplaceNULLBy = 'Substituir NULL por'; 
$strReplaceTable = 'Substituir os dados da tabela pelos do arquivo'; 
$strReplication = 'Replicao';
$strReset = 'Resetar'; 
$strResourceLimits = 'Limite dos recursos'; 
$strRestartInsertion = 'Reiniciar insero com %s registros';
$strReType = 'Re-digite'; 
$strRevokeAndDeleteDescr = 'Os usurios mantero o privilgio de USAGE at que os privilgios sejam recarregados.'; 
$strRevokeAndDelete = 'Revogar todos os privilgios ativos dos usuarios e depois apagar eles.'; 
$strRevokeMessage = 'Voc revogou os privilgios para %s'; 
$strRevoke = 'Revogar'; 
$strRomanian = 'Romno'; 
$strRoutineReturnType = 'Tipo de returno';
$strRoutines = 'Rotinas';
$strRowLength = 'Tamanho do registro'; 
$strRowsFrom = 'registro(s) comeando de'; 
$strRowSize = ' Tamanho do registro '; 
$strRowsModeFlippedHorizontal = 'horizontal (cabealhos rotacionados)'; 
$strRowsModeHorizontal = 'horizontal'; 
$strRowsModeOptions = 'no modo %s e repetindo cabealhos aps %s clulas'; 
$strRowsModeVertical = 'vertical'; 
$strRows = 'Registros'; 
$strRowsStatistic = 'Estatsticas do registros'; 
$strRunning = 'Rodando em %s'; 
$strRunQuery = 'Enviar consulta SQL'; 
$strRunSQLQuery = 'Fazer consulta SQL no Banco de Dados %s'; 
$strRunSQLQueryOnServer = 'Rodar consulta(s) SQL no servidor %s';
$strRussian = 'Russo'; 

$strSaveOnServer = 'Salvar no servidor no diretrio %s'; 
$strSavePosition = 'Salvar posio';
$strSave = 'Salvar'; 
$strScaleFactorSmall = 'A escala  muito pequena para ajustar o esquema em uma pgina'; 
$strSearchFormTitle = 'Procurar no Banco de Dados'; 
$strSearchInTables = 'Dentro da(s) tabela(s):'; 
$strSearchNeedle = 'Palavra(s) ou valor(es) para procurar (coringa: "%"):'; 
$strSearchOption1 = 'pelo menos uma das palavras'; 
$strSearchOption2 = 'todas as palavras'; 
$strSearchOption3 = 'a frase exata'; 
$strSearchOption4 = 'como expresso regular'; 
$strSearch = 'Procurar'; 
$strSearchResultsFor = 'Procurar resultados por "<i>%s</i>" %s:'; 
$strSearchType = 'Encontrar:'; 
$strSecretRequired = 'O arquivo de configurao agora precisa de uma frase secreta com senha (blowfish_secret).'; 
$strSelectADb = 'Selecionar um Banco de Dados'; 
$strSelectAll = 'Selecionar Todos'; 
$strSelectBinaryLog = 'Selecionar log binrio para exibir'; 
$strSelectFields = 'Selecionar os campos (no mnimo 1)'; 
$strSelectForeignKey = 'Selecionar Chave Estrangeira';
$strSelectNumRows = 'na consulta'; 
$strSelectReferencedKey = 'Seleciona chave referenciada';
$strSelectTables = 'Tabelas selecionadas'; 
$strSend = 'Enviado'; 
$strSent = 'Enviar'; 
$strServerChoice = 'Seleo do Servidor'; 
$strServerNotResponding = 'O servidor no est respondendo'; 
$strServer = 'Servidor'; 
$strServers = 'Servidores';
$strServerStatusDelayedInserts = 'Inseres demoradas';
$strServerStatus = 'Informaes de Runtime'; 
$strServerStatusUptime = 'Esse servidor MySQL est rodando por %s. Ele foi iniciado em %s.'; 
$strServerTabVariables = 'Variveis'; 
$strServerTrafficNotes = '<b>Trfico do servidor</b>: Essas tabelas mostram as estatsticas do trfico da rede neste servidor MySQL desde o incio.'; 
$strServerVars = 'Variveis e configuraes do servidor'; 
$strServerVersion = 'Verso do Servidor'; 
$strSessionStartupErrorGeneral = 'No pde iniciar a sesso sem erros, cheque os erros ocorridos nos logs do PHP e/ou do seu servidor web e configure a instalao do PHP corretamente.';
$strSessionValue = 'Valor da sesso'; 
$strSetEnumVal = 'Se um tipo de campo  "enum" ou "set", por favor entre valores usando este formato: \'a\',\'b\',\'c\'...<br />Se voc for colocar uma barra contrria ("\") ou aspas simples ("\'") entre os valores, coloque uma barra contrria antes (por exemplo \'\\\\xyz\' ou \'a\\\'b\').'; 
$strShowAll = 'Mostrar todos'; 
$strShowColor = 'Mostrar cor'; 
$strShowDatadictAs = 'Formato do dicionrio de dados'; 
$strShowFullQueries = 'Mostrar consultas completas'; 
$strShowGrid = 'Mostrar grade'; 
$strShowHideLeftMenu = 'Exibir/Ocultar menu da esquerda';
$strShowingBookmark = 'Exibindo marcadores';
$strShowingPhp = 'Exibindo como cdigo PHP';
$strShowingRecords = 'Mostrando registros '; 
$strShowingSQL = 'Exibindo consulta SQL';
$strShow = 'Mostrar'; 
$strShowOpenTables = 'Exibir tabelas abertas';
$strShowPHPInfo = 'Mostrar informaes do PHP'; 
$strShowSlaveHosts = 'Exibir servidores escravos';
$strShowSlaveStatus = 'Exibir status dos escravos';
$strShowStatusBinlog_cache_disk_useDescr = 'O nmero de transaes que usaram o cache do log binrio temporrio mas que excederam o valor do binlog_cache_size e usaram o arquivo temporrio para armazenar enunciados da transao.';
$strShowStatusBinlog_cache_useDescr = 'O nmero de transaes que usaram o cache do log binrio temporrio.';
$strShowStatusCreated_tmp_disk_tablesDescr = 'O nmero de tabelas temporrias no disco criadas automaticamente pelo servidor enquanto executava os enunciados. Se Created_tmp_disk_tables  grande, voc pode aumentar o valor de tmp_table_size para fazer as tabelas temporrias serem baseadas na memria ou invs de baseadas no disco';
$strShowStatusCreated_tmp_filesDescr = 'Quantos arquivos temporrios o MySQL tinha criado.';
$strShowStatusCreated_tmp_tablesDescr = 'O nmero de tabelas temporrias na memria criadas automaticamente pelo servidor enquanto executava os enunciados.';
$strShowStatusDelayed_errorsDescr = 'O nmero de linhas escritas com INSERT DELAYED para cada erro ocorrido (provavelmente chave duplicada).';
$strShowStatusDelayed_insert_threadsDescr = 'O nmero de processos manipuladores de INSERT DELAYED em uso. Cada tabela diferente em que se usa INSERT DELAYED comea seu prprio processo.';
$strShowStatusDelayed_writesDescr = 'O nmero de linhas INSERT DELAYED escritas.';
$strShowStatusFlush_commandsDescr  = 'O nmero de enunciados FLUSH executados.';
$strShowStatusHandler_commitDescr = 'O nmero de enunciados COMMIT internos.';
$strShowStatusHandler_deleteDescr = 'O nmero de vezes que uma linha foi deletada de uma tabela.';
$strShowStatusHandler_discoverDescr = 'O servidor MySQL pode perguntar ao motor de armazenamento do NDB Cluster se ele sabe sobre uma tabela com um nome dado. Isto  chamado descoberta. Handler_discover indica o nmero de vezes que tabelas foram descobertas.';
$strShowStatusHandler_read_firstDescr = 'O nmero de vezes que a primeira entrada foi lida de um ndice. Se isto for alto, sugere que o usurio est fazendo muitas varreduras completas do ndice; por exemplo, SELECT col1 FROM foo, supondo que col1  um ndice.';
$strShowStatusHandler_read_keyDescr = 'O nmero de requisies para ler uma linha baseada em uma chave. Se isto for alto,  uma boa indicao de que suas consultas e tabelas estejam corretamente indexadas.';
$strShowStatusHandler_read_nextDescr = 'O nmero de requisies para ler a linha seguinte na ordem da chave. Isto  incrementado se voc estiver consultando uma coluna do ndice com uma restrio da escala ou se voc estiver fazendo uma varredura do ndice.';
$strShowStatusHandler_read_prevDescr = 'O nmero de requisies para ler a linha precedente na ordem da chave. Este mtodo de leitura  usado principalmente para otimizar ORDER BY DESC.';
$strShowStatusHandler_read_rndDescr = 'O nmero de requisies pra ler uma linha baseada em uma posio fixa. Isto  alto se voc estiver fazendo muitas consultas que requerem a ordenao do resultado. Voc tem provavelmente muitas consultas que requerem que o MySQL faa a varredura de tabelas inteiras ou voc tem junes que no usam as chaves corretamente.';
$strShowStatusHandler_read_rnd_nextDescr = 'O nmero de requisies para ler a linha seguinte no arquivo de dados. Isto  alto se voc estiver fazendo muitas varreduras da tabela. Geralmente isto sugere que suas tabelas no esto corretamente indexadas ou que suas consultas no esto escritas para tomar vantagem dos ndices que voc tm.';
$strShowStatusHandler_rollbackDescr = 'O nmero de enunciados ROLLBACK internos.';
$strShowStatusHandler_updateDescr = 'O nmero de requisies para atualizar uma linha na tabela.';
$strShowStatusHandler_writeDescr = 'O nmero de requisies para inserir uma linha na tabela.';
$strShowStatusInnodb_buffer_pool_pages_dataDescr = 'O nmero de pginas que contm dados (sujos ou limpos).';
$strShowStatusInnodb_buffer_pool_pages_dirtyDescr = 'O nmero de pginas atualmente sujas.';
$strShowStatusInnodb_buffer_pool_pages_flushedDescr = 'O nmero de pginas do buffer pool que foram requisitadas para serem niveladas.';
$strShowStatusInnodb_buffer_pool_pages_freeDescr = 'O nmero de pginas livres.';
$strShowStatusInnodb_buffer_pool_pages_latchedDescr = 'O nmero de pginas trancadas no buffer pool do InnoDB. Estas so pginas que esto sendo lidas ou escritas atualmente ou aquela no pode ser nivelada ou removido por alguma outra razo.';
$strShowStatusInnodb_buffer_pool_pages_miscDescr = 'O nmero de pginas ocupadas porque foram alocados para rotinas administrativas tais como trancamento de linhas ou ndice hash adaptvel. Este valor pode tambm ser calculado como Innodb_buffer_pool_pages_total - Innodb_buffer_pool_pages_free - Innodb_buffer_pool_pages_data.';
$strShowStatusInnodb_buffer_pool_pages_totalDescr = 'Tamanho total do buffer pool, em pginas.';
$strShowStatusInnodb_buffer_pool_read_ahead_rndDescr = 'O nmero de ler-adiante "aleatrios" InnoDB iniciado. Isto acontece quando uma consulta faz a varredura de uma parcela grande de uma tabela mas na ordem aleatria.';
$strShowStatusInnodb_buffer_pool_read_ahead_seqDescr = 'O nmero de ler-adiante sequenciais InnoDB iniciado. Isto acontece quando o InnoDB faz uma varredura sequencial completa da tabela.';
$strShowStatusInnodb_buffer_pool_read_requestsDescr = 'O nmero de requisies de leitura lgica InnoDB que foram feitas.';
$strShowStatusInnodb_buffer_pool_readsDescr = 'O nmero de leituras lgicas que o InnoDB no pode satisfer do buffer pool e teria que fazer uma leitura de pgina simples';
$strShowStatusInnodb_buffer_pool_wait_freeDescr = 'Normalmente, escreve para o buffer pool do InnoDB rodando em segundo plano. Entretanto, se for necessrio ler ou criar uma pgina e nenhuma pgina limpa estiver disponvel,  necessrio esperar as pginas serem niveladas primeiramente. Este contador conta instncias dessas esperas. Se o tamanho do buffer pool for ajustado corretamente, este valor deve ser pequeno.';
$strShowStatusInnodb_buffer_pool_write_requestsDescr = 'O nmero de escritas feitas para o buffer pool do InnoDB.';
$strShowStatusInnodb_data_fsyncsDescr = 'O nmero de operaes fsync()  fazer.';
$strShowStatusInnodb_data_pending_fsyncsDescr = 'O nmero atual de operaes fsync() pendentes.';
$strShowStatusInnodb_data_pending_readsDescr = 'O nmero atual de leituras pendentes.';
$strShowStatusInnodb_data_pending_writesDescr = 'O nmero atual de escritas pendentes.';
$strShowStatusInnodb_data_readDescr = 'O montante de leitura de dados  fazer, em bytes.';
$strShowStatusInnodb_data_readsDescr = 'O nmero total de dados lidos.';
$strShowStatusInnodb_data_writesDescr = 'O nmero total de dados escritos.';
$strShowStatusInnodb_data_writtenDescr = 'O montante de escrita de dados  fazer, em bytes.';
$strShowStatusInnodb_dblwr_pages_writtenDescr = 'O nmero de escritas doublewrite que foram executadas e o nmero de pginas que foram escritas para esta finalidade.';
$strShowStatusInnodb_dblwr_writesDescr = 'O nmero de escritas doublewrite que foram executadas e o nmero de pginas que foram escritas para esta finalidade.';
$strShowStatusInnodb_log_waitsDescr = 'O nmero de esperas geradas porque o buffer do log era muito pequeno e teve que esperar que fosse nivelada antes de continuar.';
$strShowStatusInnodb_log_write_requestsDescr = 'O nmero de requisies de escrita de log.';
$strShowStatusInnodb_log_writesDescr = 'O nmero de escritas fsicas para o arquivo de log.';
$strShowStatusInnodb_os_log_fsyncsDescr = 'O nmero de escritas fsyncs feitas no arquivo de log.';
$strShowStatusInnodb_os_log_pending_fsyncsDescr = 'O nmero de arquivos de log fsyncs pendentes.';
$strShowStatusInnodb_os_log_pending_writesDescr = 'Escrita de arquivos de log pendentes.';
$strShowStatusInnodb_os_log_writtenDescr = 'O nmero de bytes escritos para o arquivo de log.';
$strShowStatusInnodb_pages_createdDescr = 'O nmero de pginas criadas.';
$strShowStatusInnodb_page_sizeDescr = 'O tamanho de pgina compilada do InnoDB (padro 16KB). Muitos valores so contados em pginas; o tamanho de pgina permite que sejam facilmente convertidos em bytes.';
$strShowStatusInnodb_pages_readDescr = 'O nmero de pginas lidas.';
$strShowStatusInnodb_pages_writtenDescr = 'O nmero de pginas escritas.';
$strShowStatusInnodb_row_lock_current_waitsDescr = 'O nmero de linhas trancadas que esto esperando atualmente.';
$strShowStatusInnodb_row_lock_time_avgDescr = 'O tempo mdio para recuperar uma linha trancada, em milsegundo.';
$strShowStatusInnodb_row_lock_timeDescr = 'O tempo total gasto para recuperar linhas trancadas, em milsegundo.';
$strShowStatusInnodb_row_lock_time_maxDescr = 'O mximo de tempo para recuperar uma linha trancada, em milsegundo.';
$strShowStatusInnodb_row_lock_waitsDescr = 'O nmero de vezes que uma linhas trancada teve que esperar para ser escrita.';
$strShowStatusInnodb_rows_deletedDescr = 'O nmero de linhas deletadas de tabelas InnoDB.';
$strShowStatusInnodb_rows_insertedDescr = 'O nmero de linhas inseridas em tabelas InnoDB.';
$strShowStatusInnodb_rows_readDescr = 'O nmero de linhas lidas de tabelas InnoDB.';
$strShowStatusInnodb_rows_updatedDescr = 'O nmero de linhas atualizadas em tabelas InnoDB.';
$strShowStatusKey_blocks_not_flushedDescr = 'O nmero de blocos chave no cache chave que mudaram mas no foram nivelados ainda ao disco. Antes era chamado de Not_flushed_key_blocks.';
$strShowStatusKey_blocks_unusedDescr = 'O nmero de blocos no usados no cache chave. Voc pode usar este valor para determinar quanto do cache chave est no uso.';
$strShowStatusKey_blocks_usedDescr = 'O nmero de blocos usados no cache chave. Este valor  uma marca d\'gua que indica o nmero mximo de blocos que estiveram sempre em uso em algum momento.';
$strShowStatusKey_read_requestsDescr = 'O nmero de requisies para ler um bloco chave do cache.';
$strShowStatusKey_readsDescr = 'O nmero de leituras fsicas de um bloco chave do disco. Se Key_reads for alto, ento seu valor do key_buffer_size  provavelmente muito baixo. A taxa de falta de cache pode ser calculada como Key_reads/Key_read_requests.';
$strShowStatusKey_write_requestsDescr = 'O nmero de requisies para escrever um bloco chave para o cache.';
$strShowStatusKey_writesDescr = 'O nmero de escritas fsicas para um bloco chave para o disco.';
$strShowStatusLast_query_costDescr = 'O custo total da ltima consulta compilada como computado pelo otimizador de consultas. til para comparar o custo de diferentes planos de consulta para a mesma consulta. O valor padro 0 significa que nenhuma consulta foi compilada ainda.';
$strShowStatusNot_flushed_delayed_rowsDescr = 'O nmero de linhas esperando para serem escritas na fila de INSERT DELAYED.';
$strShowStatusOpened_tablesDescr = 'O nmero de tabelas que devem estar abertas. Se aberta, as tabelas so grandes, o valor do cache de suas tabelas  provavelmente muito pequeno.';
$strShowStatusOpen_filesDescr = 'O nmero de arquivos que esto abertos.';
$strShowStatusOpen_streamsDescr = 'O nmero de streams que esto abertos (usados principalmente para log).';
$strShowStatusOpen_tablesDescr = 'O nmero de tabelas que esto abertas.';
$strShowStatusQcache_free_blocksDescr = 'O nmero de blocos de memria livre na consulta do cache.';
$strShowStatusQcache_free_memoryDescr = 'O montante de memria livre para a consulta do cache.';
$strShowStatusQcache_hitsDescr = 'O nmero de hits do cache.';
$strShowStatusQcache_insertsDescr = 'O nmero de consultas adicionadas no cache.';
$strShowStatusQcache_lowmem_prunesDescr = 'O nmero de consultas que foram removidas do cache para liberar memria para novas consultas. Essa informao pode ajudar voc a ajustar o tamanho da consulta do cache. A consulta do cache usa a estratgia do "usado menos recentemente" (LRU - least recently used) para decidir qual consulta remover do cache.';
$strShowStatusQcache_not_cachedDescr = 'O nmero de consultas sem cache (no cachevel, ou no pode ser cachevel devido  configurao em query_cache_type).';
$strShowStatusQcache_queries_in_cacheDescr = 'O nmero de consultas registradas no cache.';
$strShowStatusQcache_total_blocksDescr = 'O nmero total de blocos na consulta do cache.';
$strShowStatusReset = 'Resetar';
$strShowStatusRpl_statusDescr = 'O status da replicao  prova de falhas (no implementado).';
$strShowStatusSelect_full_joinDescr = 'O nmero de junes que no usaram ndices. Se este valor no for 0, voc deve cuidadosamente verificar os ndices de suas tabelas.';
$strShowStatusSelect_full_range_joinDescr = 'O nmero de junes que usaram uma pesquisa de escala na tabela de referncia.';  //est correto isso?
$strShowStatusSelect_range_checkDescr = 'O nmero de junes sem chaves que verificam para ver se h o uso da chave aps cada linha. (Se este no for 0, voc deve cuidadosamente verificar os ndices de suas tabelas.)';
$strShowStatusSelect_rangeDescr = 'O nmero de junes que usaram escalas na primeira tabela. (No  normalmente crtico mesmo se este for grande.)';
$strShowStatusSelect_scanDescr = 'O nmero junes que fez uma varredura completa da primeira tabela.';
$strShowStatusSlave_open_temp_tablesDescr = 'O nmero de tabelas temporrias abertas atualmente pelo processo SQL escravo.';
$strShowStatusSlave_retried_transactionsDescr = 'Nmero total (desde o incio) de vezes que o processo SQL escravo de replicao teve que tentar transaes.';
$strShowStatusSlave_runningDescr = 'Isto  ON se este servidor  um escravo conectado  um mestre.';
$strShowStatusSlow_launch_threadsDescr = 'O nmero de processos que levaram mais que slow_launch_time segundos para serem criadas.';
$strShowStatusSlow_queriesDescr = 'O nmero de consultas que levaram mais que long_query_time segundos.';
$strShowStatusSort_merge_passesDescr = 'O nmero de fuses que o algoritmo de ordenao teve que fazer. Se este valor for alto, voc deve considerar aumentar o valor da varivel sort_buffer_size do sistema.';
$strShowStatusSort_rangeDescr = 'O nmero de ordenaes que foram feitas com escalas.';  //est correto isso? ranges = escalas??
$strShowStatusSort_rowsDescr = 'O nmero de linhas ordenadas.';
$strShowStatusSort_scanDescr = 'O nmero de ordenaes que foram feitas scaneando a tabela.';
$strShowStatusTable_locks_immediateDescr = 'O nmero de vezes que uma tabela trancada foi recuperada imediatamente.';
$strShowStatusTable_locks_waitedDescr = 'O nmero de vezes que uma tabela trancada no foi recuperada imediatamente e uma espera foi necessria. Se isso foi alto e voc tem problemas de performance, voc precisa primeiramente otimizar suas consultas e ento, ou dividir sua tabela ou usar replicao.';
$strShowStatusThreads_cachedDescr = 'O nmero de processos no cache de processos. A taxa de hits do cache pode ser calculada como Threads_created/conexes. Se este valor for vermelho voc deve aumentar seu thread_cache_size';
$strShowStatusThreads_connectedDescr = 'O nmero de conexes atualmente abertas.';
$strShowStatusThreads_createdDescr = 'O nmero de processos criadas para manipular conexes. Se Threads_created  grande, voc deveria aumentar o valor de thread_cache_size. (Normalmente isso no da um aumento notvel de performance se voc tem uma boa implementao de processos.)';
$strShowStatusThreads_runningDescr = 'O nmero de processos que no esto dormindo.';
$strShowTableDimension = 'Mostrar dimenso das tabelas'; 
$strShowTables = 'Mostrar tabelas'; 
$strShowThisQuery = ' Mostrar esta consulta SQL novamente '; 
$strSimplifiedChinese = 'Chins Simplificado'; 
$strSingly = '(singularmente)'; 
$strSize = 'Tamanho'; 
$strSkipQueries = 'Nmero de registros (consultas) ignoradas no incio';
$strSlovak = 'Eslovquio'; 
$strSlovenian = 'Eslovnio'; 
$strSmallBigAll = 'Tudo Pequeno/Grande';
$strSnapToGrid = 'Ajustar  grade';
$strSocketProblem = '(ou o soquete do servidor MySQL local no est configurado corretamente)';
$strSortByKey = 'Ordenar pela chave'; 
$strSorting = 'Ordenando';
$strSort = 'Ordenar'; 
$strSpaceUsage = 'Uso do espao'; 
$strSpanish = 'Espanhol'; 
$strSplitWordsWithSpace = 'Palavras so separadas por um caracter de espao (" ").'; 
$strSQLCompatibility = 'Modo de compatibilidade SQL';
$strSQLExportType = 'Tipo de exportao'; 
$strSQLParserBugMessage = 'Talvez tenha encontrado um bug no analizador (parser) do SQL. Analise a sua Consulta SQL com ateno, e verifique se as aspas esto corretas e no esto desencontradas. Outra possibilidade de falha  o fato de estar tentando subir um arquivo com sada binria de uma rea de texto citada. Pode tambm experimentar a sua consulta SQL no prompt de comandos do MySQL. A sada de erro do MySQL, isto se existir alguma, tambm poder ajudar a diagnosticar o problema. Se continuar a ter problemas ou se o analisador (parser) falhar onde a interface da linha de comandos tiver sucesso, reduza por favor a entrada da consulta SQL at aquele que causou o problema, e envie o relatrio de bug com os dados do chunk da seo CORTE abaixo:'; 
$strSQLParserUserError = 'Parece haver um erro na sua consulta SQL. A sada do servidor MySQL abaixo, isto se existir alguma, tambm poder ajudar a diagnosticar o problema.'; 
$strSQLQuery = 'consulta SQL'; 
$strSQLResult = 'Resultado SQL'; 
$strSQL = 'SQL'; 
$strSQPBugInvalidIdentifer = 'Identificador invlido'; 
$strSQPBugUnclosedQuote = 'Aspas no fechada'; 
$strSQPBugUnknownPunctuation = 'String de pontuao desconhecida'; 
$strStandInStructureForView = 'Estrutura stand-in para visualizar';
$strStatCheckTime = 'ltima verificao'; 
$strStatCreateTime = 'Criao'; 
$strStatement = 'Comandos'; 
$strStatisticsOverrun = 'Em servidores ocupados, os contadores de byte podem sobrecarregar, ento as estatsticas como relatadas pelo servidor MySQL podem estar incorretas.';
$strStatUpdateTime = 'ltima atualizao'; 
$strStatus = 'Status'; 
$strStorageEngines = 'Storage Engines'; // sem traducao
$strStorageEngine = 'Storage Engine'; // sem traducao
$strStrucCSV = 'Dados CSV'; 
$strStrucData = 'Estrutura e dados'; 
$strStrucExcelCSV = 'CSV para dados MS Excel'; 
$strStrucNativeExcel = 'Dados nativos do MS Excel'; 
$strStrucOnly = 'Somente estrutura'; 
$strStructPropose = 'Propor estrutura da tabela'; 
$strStructure = 'Estrutura'; 
$strStructureForView = 'Estrutura para visualizar';
$strSubmit = 'Submeter'; 
$strSuccess = 'Seu comando SQL foi executado com sucesso'; 
$strSum = 'Soma'; 
$strSwedish = 'Suco'; 
$strSwitchToDatabase = 'Mudar para o Banco de Dados copiado'; 
$strSwitchToTable = 'Mudar para a tabela copiada'; 

$strTableAlreadyExists = 'Tabela %s j existe!';
$strTableComments = 'Comentrios da tabela'; 
$strTableEmpty = 'O Nome da Tabela est vazio!'; 
$strTableHasBeenDropped = 'Tabela %s foi eliminada'; 
$strTableHasBeenEmptied = 'Tabela %s foi esvaziada'; 
$strTableHasBeenFlushed = 'Tabela %s foi limpa'; 
$strTableIsEmpty = 'Tabela para estar vazia!';
$strTableMaintenance = 'Tabela de Manuteno'; 
$strTableName = 'Nome da Tabela';
$strTableOfContents = 'Tabela de contedos'; 
$strTableOptions = 'Opes da tabela'; 
$strTables = '%s tabela(s)'; 
$strTableStructure = 'Estrutura da tabela'; 
$strTable = 'Tabela'; 
$strTakeIt = 'tome'; 
$strTblPrivileges = 'Privilgios especficos da tabela'; 
$strTempData = 'Dados temporrios';
$strTextAreaLength = ' Por causa da sua largura,<br /> esse campo pode no ser editvel '; 
$strThai = 'Thailands'; 
$strThemeDefaultNotFound = 'Tema padro %s no encontrado!';
$strThemeNoPreviewAvailable = 'Nenhuma pr-visualizao disponvel.';
$strThemeNotFound = 'Tema %s no encontrado!';
$strThemeNoValidImgPath = 'Encontrado caminho invlido para imagens para o tema %s!';
$strThemePathNotFound = 'Encontrado caminho invlido para o tema %s!';
$strTheme = 'Tema / Estilo'; 
$strThisHost = 'Esse Servidor'; 
$strThreads = 'Processos';
$strThreadSuccessfullyKilled = 'Processo %s foi morto com sucesso.'; 
$strTimeoutInfo = 'Importao anterior passou do tempo limite, depois de reenviar, ir continuar na posio %d.';
$strTimeoutNothingParsed = 'Entretanto na ltima vez nenhum dado foi passado, isso normalmente significa que o phpMyAdmin no  capaz de finalizar essa importao  menos que voc aumente o tempo limite do PHP.';
$strTimeoutPassed = 'Script passou do tempo limite, se voc deseja terminar a importao, reenvie o mesmo arquivo que a importao ser resumida.';
$strTime = 'Tempo'; 
$strToFromPage = 'pgina de/para';
$strToggleScratchboard = 'mudar o estado do Scratchboard'; //isso est correto? mas nao descobri o q eh
$strToggleSmallBig = 'Mudar para pequeno/grande';
$strToSelectRelation = 'Para selecionar relacionamento, clique :';
$strTotal = 'total'; 
$strTotalUC = 'Total'; 
$strTraditionalChinese = 'Chins Tradicional'; 
$strTraditionalSpanish = 'Espanhol Traditional'; 
$strTraffic = 'Trfego'; 
$strTransactionCoordinator = 'Coordenador da transao';
$strTransformation_application_octetstream__download = 'Mostrar o link para baixar os dados binrios do campo. Primeira opo  o nome do arquivo binrio. Segunda opo  um possvel nome de campo de uma linha da tabela que contm o nome do arquivo. Se voc usar a segunda opo precisa colocar na primeira opo uma string em branco'; 
$strTransformation_application_octetstream__hex = 'Exibir representao hexadecimal dos dados. Primeiro parmetro opcional especifica como frequentemente espaos sero adicionados (padro para 2 mordidelas).';  //ta certo isso? nibbles, traduzi como mordidelas
$strTransformation_image_jpeg__inline = 'Mostrar uma miniatura clicvel; opes: largura,altura em pixels (mantm a proporo original)'; 
$strTransformation_image_jpeg__link = 'Mostrar o link para esta imagem (ex.: blob download direto).'; 
$strTransformation_image_png__inline = 'Ver imagem/jpeg: em linha'; 
$strTransformation_text_plain__dateformat = 'Exibir um TIME, TIMESTAMP, DATETIME ou campo numrico unix timestamp formatado como data. A primeira opo  o offset (em horas) que ser adicionado ao timestamp (Padro: 0). Use a segunda opo para especificar uma string de formatao data/tempo diferente. A terceira opo determina se voc deseja ver data local ou UTC (use a string "local" ou "utc") para isso. De acordo com isso, o formatdo da data ter valores diferentes - para "local" veja a documentao do PHP para funo strftime() e para "utc" isso  feito usando a funo gmdate().';
$strTransformation_text_plain__external = 'LINUX APENAS: Rode uma aplicao externa e alimente os campos de dados pela entrada padro. Retorna a sada padro da aplicao. Padro  Limpo, para uma bonita impresso do cdigo HTML. Por razes de segurana, voc deve editar manualmente o arquivo libraries/transformations/text_plain__external.inc.php e inserir as ferramentas que voc permite rodar. A primeira opo  o nmero do programa que voc quer rodar e a segunda opo so os parmetros para o programa. A terceira opo, se setada para 1 ir converter a sada usando htmlspecialchars() (Padro  1). A quarta opo, se setada como 1 ir por um NOWRAP para o contedo da clula, de forma que a sada inteira ser mostrada sem reformatao(Padro  1)'; 
$strTransformation_text_plain__formatted = 'Preservar a formatao original campo. Sem escape.'; 
$strTransformation_text_plain__imagelink = 'Mostrar uma imagem e um link, o campo contm um nome de arquivo; primeira opo  um prefixo tipo "http://domain.com/", segunda opo  a largura em pixels, o terceiro  a altura.'; 
$strTransformation_text_plain__link = 'Mostrar um link, o campo contm o nome do arquivo, primeira opo  um prefixo tipo "http://domain.com/", segunda opo  um ttulo para o link.'; 
$strTransformation_text_plain__sql = 'Formatar texto como consulta SQL com sntaxe colorida.';
$strTransformation_text_plain__substr = 'Mostrar apenas parte da string. Primeira opo  um offset para definir onde a sada do seu texto deve iniciar (Padro: 0). Segunda opo  o quanto do texto dever ser retornado. Se estiver em branco, retorna todo o restante do texto. Terceira opo define quais caracteres sero acrescentados na substring retornada (Padro: ...).'; 
$strTriggers = 'Gatilhos';
$strTruncateQueries = 'Truncar as consultas SQL exibidas'; 
$strTurkish = 'Turco'; 
$strType = 'Tipo'; 

$strUkrainian = 'Ucraniano'; 
$strUncheckAll = 'Desmarcar todos'; 
$strUnicode = 'Unicode'; 
$strUnique = 'nico'; 
$strUnknown = 'desconhecido'; 
$strUnselectAll = 'Desmarcar Todos'; 
$strUnsupportedCompressionDetected = 'Voc tentou carregar um arquivo com compresso no suportada (%s). Pode o suporte para isso no ter sido implementado ou pode ter sido desabilitado por sua configurao PHP.';
$strUpdatePrivMessage = 'Voc mudou os privilios para %s.'; 
$strUpdateProfileMessage = 'A configurao foi atualizada.'; 
$strUpdateQuery = 'Atualizar a consulta SQL'; 
$strUpdComTab = 'Consulte a documentao sobre como atualizar sua tabela Column_comments'; 
$strUpgrade = 'Voc deveria atualizar para %s %s ou posterior.'; 
$strUploadErrorCantWrite = 'Falhou ao salvar arquivo no disco.';
$strUploadErrorExtension = 'Carregamento do arquivo parado pela exteno.';
$strUploadErrorFormSize = 'O arquivo carregado excede o tamanho definido na diretriz MAX_FILE_SIZE do formulrio HTM.';
$strUploadErrorIniSize = 'O arquivo carregado excede o tamanho definido na diretriz upload_max_filesize no php.ini.';
$strUploadErrorNoTempDir = 'Pasta temporria no encontrada.';
$strUploadErrorPartial = 'Carregamento do arquivo foi apenas parcial.';
$strUploadErrorUnknown = 'Erro desconhecido no carregamento do arquivo.';
$strUploadLimit = 'Voc provavelmente tentou carregar um arquivo muito grande. Veja referncias na %sdocumentation%s para burlar esses limites.';
$strUploadsNotAllowed = 'No  permitido subir arquivos neste servidor.';
$strUsage = 'Uso'; 
$strUseBackquotes = 'Usar aspas simples nos nomes de tabelas e campos'; 
$strUsedPhpExtensions = 'Extenses PHP usadas';
$strUseHostTable = 'Usar Tabela do Servidor'; 
$strUserAlreadyExists = 'O usurio %s j existe!'; 
$strUserEmpty = 'O nome do usurio est em branco!'; 
$strUserName = 'Nome do usurio'; 
$strUserNotFound = 'O usurio selecionado no foi encontrado na tabela de privilgios.'; 
$strUserOverview = 'Avaliao dos usurios'; 
$strUsersDeleted = 'Os usurios selecionados foram apagados com sucesso.'; 
$strUsersHavingAccessToDb = 'Usurios que tm acesso  &quot;%s&quot;'; 
$strUser = 'Usurio'; 
$strUseTabKey = 'Usar a teclar TAB para se mover de valor em valor, ou CTRL+setas para mover em qualquer direo'; 
$strUseTables = 'Usar tabelas'; 
$strUseTextField = 'Usar campo texto'; 
$strUseThisValue = 'Usar este valor'; 

$strValidateSQL = 'Validar SQL'; 
$strValidatorError = 'O Validador SQL no pode ser inicializado. Verifique se voc instalou a exteno necessria do php conforme est escrito em %sdocumentation%s.'; 
$strValue = 'Valor'; 
$strVar = 'Variveis'; 
$strVersionInformation = 'Informaes da verso';
$strViewDumpDatabases = 'Ver dump (esquema) dos Bancos de Dados'; 
$strViewDumpDB = 'Ver o esquema do Banco de Dados'; 
$strViewDump = 'Ver o esquema da tabela'; 
$strViewHasBeenDropped = 'Viso %s foi apagada';
$strViewMaxExactCount = 'Essa viso tem mais que %s linhas. Veja referncias na %sdocumentation%s.';
$strViewName = 'Nome da VISO';
$strView = 'Viso';

$strWebServerUploadDirectoryError = 'O diretrio que voc especificou para subir arquivos no foi encontrado.'; 
$strWebServerUploadDirectory = 'Servidor web subiu o diretrio'; 
$strWelcome = 'Bem vindo ao %s'; 
$strWestEuropean = 'Oeste Europeu'; 
$strWildcard = 'coringa'; 
$strWindowNotFound = 'A janela alvo do navegador no pode ser atualizada. Talvez voc tenha fechado a janela alvo ou o seu navegador tenha bloqueado a comunicao entre janelas nas configuraes de segurana.'; 
$strWithChecked = 'Com marcados:'; 
$strWriteRequests = 'Escrita requisitada';
$strWrongUser = 'Usurio ou senha incorreta. Acesso negado.'; 

$strXML = 'XML'; 

$strYes = 'Sim'; 

$strZeroRemovesTheLimit = 'Nota: Ajustar essa opo para 0 (zero) remove os limites.'; 
$strZip = '"compactado com zip"'; 

$strProfiling = 'Profiling';  //to translate
$strSuhosin = 'Server running with Suhosin. Please refer to %sdocumentation%s for possible issues.';  //to translate
?>
